@@ -3,7 +3,6 @@ package MyApp::Client;
 use strict;
 use warnings;
 
-use AnyEvent::Impl::Perl;
 use MyApp::Service::Chat;
 use MyApp::Service::Auth;
 
@@ -53,7 +52,12 @@ sub run {
         print $msg{from} . ": " if $msg{from};
         print $msg{message} . "\n";
     });
- 
+
+    if ($ARGV[-1] eq '--test') { 
+        $self->run_tests; 
+        exit;
+    }
+
     $self->{hdl} = AnyEvent::Handle->new( fh => $self->{fh} );
 
     $self->{auth}->login( username => getpwuid($>), password => '123' );
@@ -122,4 +126,23 @@ sub process_cmd {
     }
 }
 
+sub run_tests {
+    my $self = shift;
+
+    my @cmds = (
+        '/login Dave 123',
+        'Public message',
+        '/pm Dave Private message',
+        '/logout',
+        '/login Zoe 123',
+        'Hello',
+        '/ping',
+        '/kick Zoe',
+    );
+
+    foreach my $cmd (@cmds) {
+        $self->process_cmd("$cmd\n");
+    }
+}
+
 1;
