@@ -3,7 +3,7 @@ package MyApp::Service::Flood::Worker;
 use strict;
 use warnings;
 
-use Beekeeper::Worker;
+use Beekeeper::Worker ':log';
 use base 'Beekeeper::Worker';
 
 
@@ -14,6 +14,12 @@ sub on_startup {
         'myapp.flood.echo'  => 'echo',
         'myapp.flood.delay' => 'delayed_echo',
     );
+
+    $self->accept_notifications(
+        'myapp.flood.msg'   => 'message',
+    );
+
+    log_info "Ready";
 }
 
 sub authorize_request {
@@ -29,6 +35,10 @@ sub echo {
     return $params;
 }
 
+sub message {
+    my ($self, $params) = @_;
+}
+
 sub delayed_echo {
     my ($self, $params, $request) = @_;
 
