@@ -3,9 +3,8 @@ package Beekeeper::Service::ToyBroker::Worker;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.07';
 
-use AnyEvent::Impl::Perl;
 use Beekeeper::Worker ':log';
 use base 'Beekeeper::Worker';
 
@@ -1505,18 +1504,21 @@ __END__
 
 =head1 NAME
 
-Beekeeper::Service::ToyBroker::Worker - Basic MQTT 5 broker
+Beekeeper::Service::ToyBroker::Worker - Basic MQTT 5.0 broker
 
 =head1 VERSION
 
-Version 0.05
+Version 0.07
 
 =head1 DESCRIPTION
 
-ToyBroker implements a small MQTT subset needed to run a Beekeeper worker pool.
+ToyBroker implements a small MQTT 5.0 subset needed to run a Beekeeper worker pool.
 
-Being single threaded it does not scale at all, but it is suitable for development
-or running tests.
+It is intended to be used for development or running tests only. For production
+work a real broker (like Mosquitto, HiveMQ, VerneMQ...) is needed.
+
+A ToyBroker will be started automatically in any pool which has C<use_toybroker> 
+option set to a true value in its config file C<pool.config.json>.
 
 ToyBroker is configured from file C<toybroker.config.json>, which is looked for 
 in ENV C<BEEKEEPER_CONFIG_DIR>, C<~/.config/beekeeper> and then C</etc/beekeeper>.
